@@ -161,16 +161,16 @@ int main(int argc, char* argv[])
 
   e.load_platform(argv[1]);
 
-  simgrid::s4u::Actor::create("broadcaster", simgrid::s4u::Host::by_name("node-0.simgrid.org"), broadcaster, 8, 256);
+  simgrid::s4u::Actor::create("broadcaster", e.host_by_name("node-0.simgrid.org"), broadcaster, 8, 256);
 
-  simgrid::s4u::Actor::create("peer", simgrid::s4u::Host::by_name("node-1.simgrid.org"), peer);
-  simgrid::s4u::Actor::create("peer", simgrid::s4u::Host::by_name("node-2.simgrid.org"), peer);
-  simgrid::s4u::Actor::create("peer", simgrid::s4u::Host::by_name("node-3.simgrid.org"), peer);
-  simgrid::s4u::Actor::create("peer", simgrid::s4u::Host::by_name("node-4.simgrid.org"), peer);
-  simgrid::s4u::Actor::create("peer", simgrid::s4u::Host::by_name("node-5.simgrid.org"), peer);
-  simgrid::s4u::Actor::create("peer", simgrid::s4u::Host::by_name("node-6.simgrid.org"), peer);
-  simgrid::s4u::Actor::create("peer", simgrid::s4u::Host::by_name("node-7.simgrid.org"), peer);
-  simgrid::s4u::Actor::create("peer", simgrid::s4u::Host::by_name("node-8.simgrid.org"), peer);
+  simgrid::s4u::Actor::create("peer", e.host_by_name("node-1.simgrid.org"), peer);
+  simgrid::s4u::Actor::create("peer", e.host_by_name("node-2.simgrid.org"), peer);
+  simgrid::s4u::Actor::create("peer", e.host_by_name("node-3.simgrid.org"), peer);
+  simgrid::s4u::Actor::create("peer", e.host_by_name("node-4.simgrid.org"), peer);
+  simgrid::s4u::Actor::create("peer", e.host_by_name("node-5.simgrid.org"), peer);
+  simgrid::s4u::Actor::create("peer", e.host_by_name("node-6.simgrid.org"), peer);
+  simgrid::s4u::Actor::create("peer", e.host_by_name("node-7.simgrid.org"), peer);
+  simgrid::s4u::Actor::create("peer", e.host_by_name("node-8.simgrid.org"), peer);
 
   e.run();
   XBT_INFO("Total simulation time: %e", simgrid::s4u::Engine::get_clock());
