@@ -59,7 +59,7 @@ int main(int argc, char* argv[])
 {
   simgrid::s4u::Engine e(&argc, argv);
   e.load_platform(argv[1]);
-  simgrid::s4u::Actor::create("worker", simgrid::s4u::Host::by_name("Tremblay"), worker);
+  simgrid::s4u::Actor::create("worker", e.host_by_name("Tremblay"), worker);
   e.run();
 
   return 0;
