@@ -3,24 +3,15 @@
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#include "simgrid/s4u/Actor.hpp"
-#include "mc/mc.h"
-#include "simgrid/Exception.hpp"
-#include "simgrid/s4u/Exec.hpp"
+#include <simgrid/Exception.hpp>
+#include <simgrid/s4u/Actor.hpp>
+#include <simgrid/s4u/Host.hpp>
+
 #include "src/kernel/EngineImpl.hpp"
-#include "src/kernel/activity/CommImpl.hpp"
-#include "src/kernel/activity/ExecImpl.hpp"
-#include "src/kernel/activity/IoImpl.hpp"
-#include "src/kernel/activity/SleepImpl.hpp"
-#include "src/kernel/activity/SynchroRaw.hpp"
-#include "src/mc/mc_replay.hpp"
-#include "src/mc/remote/AppSide.hpp"
-#include "src/simix/smx_private.hpp"
 #if HAVE_SMPI
 #include "src/smpi/include/private.hpp"
 #endif
 #include "src/surf/HostImpl.hpp"
-#include "src/surf/cpu_interface.hpp"
 
 #include <boost/core/demangle.hpp>
 #include <typeinfo>
@@ -35,7 +26,7 @@ XBT_LOG_NEW_DEFAULT_SUBCATEGORY(simix_process, simix, "Logging specific to SIMIX
  *
  * @return The SIMIX process
  */
-smx_actor_t SIMIX_process_self()
+smx_actor_t SIMIX_process_self() // XBT_ATTRIB_DEPRECATED_v333
 {
   return simgrid::kernel::actor::ActorImpl::self();
 }
@@ -69,12 +60,12 @@ ActorImpl::ActorImpl(xbt::string name, s4u::Host* host) : host_(host), name_(std
 {
   pid_            = maxpid++;
   simcall_.issuer_ = this;
-  stacksize_      = smx_context_stack_size;
+  stacksize_       = context::stack_size;
 }
 
 ActorImpl::~ActorImpl()
 {
-  if (simix_global != nullptr && not simix_global->is_maestro(this))
+  if (EngineImpl::has_instance() && not EngineImpl::get_instance()->is_maestro(this))
     s4u::Actor::on_destruction(*get_ciface());
 }
 
@@ -103,8 +94,7 @@ ActorImplPtr ActorImpl::attach(const std::string& name, void* data, s4u::Host* h
   actor->code_ = nullptr;
 
   XBT_VERB("Create context %s", actor->get_cname());
-  xbt_assert(simix_global != nullptr, "simix is not initialized, please call MSG_init first");
-  actor->context_.reset(simix_global->get_context_factory()->attach(actor));
+  actor->context_.reset(engine->get_context_factory()->attach(actor));
 
   /* Add the actor to it's host actor list */
   host->get_impl()->add_actor(actor);
@@ -179,7 +169,7 @@ void ActorImpl::cleanup()
 
   XBT_DEBUG("%s@%s(%ld) should not run anymore", get_cname(), get_host()->get_cname(), get_pid());
 
-  if (simix_global->is_maestro(this)) /* Do not cleanup maestro */
+  if (EngineImpl::get_instance()->is_maestro(this)) /* Do not cleanup maestro */
     return;
 
   XBT_DEBUG("Cleanup actor %s (%p), waiting synchro %p", get_cname(), this, waiting_synchro_.get());
@@ -236,7 +226,8 @@ void ActorImpl::exit()
 
 void ActorImpl::kill(ActorImpl* actor) const
 {
-  xbt_assert(not simix_global->is_maestro(actor), "Killing maestro is a rather bad idea");
+  auto* engine = EngineImpl::get_instance();
+  xbt_assert(not engine->is_maestro(actor), "Killing maestro is a rather bad idea");
   if (actor->finished_) {
     XBT_DEBUG("Ignoring request to kill actor %s@%s that is already dead", actor->get_cname(),
               actor->host_->get_cname());
@@ -251,7 +242,7 @@ void ActorImpl::kill(ActorImpl* actor) const
   if (actor == this) {
     XBT_DEBUG("Go on, this is a suicide,");
   } else
-    EngineImpl::get_instance()->add_actor_to_run_list(actor);
+    engine->add_actor_to_run_list(actor);
 }
 
 void ActorImpl::kill_all() const
@@ -335,7 +326,7 @@ void ActorImpl::undaemonize()
 
 s4u::Actor* ActorImpl::restart()
 {
-  xbt_assert(not simix_global->is_maestro(this), "Restarting maestro is not supported");
+  xbt_assert(not EngineImpl::get_instance()->is_maestro(this), "Restarting maestro is not supported");
 
   XBT_DEBUG("Restarting actor %s on %s", get_cname(), host_->get_cname());
 
@@ -429,11 +420,11 @@ void ActorImpl::throw_exception(std::exception_ptr e)
 
 void ActorImpl::simcall_answer()
 {
-  if (not simix_global->is_maestro(this)) {
+  auto* engine = EngineImpl::get_instance();
+  if (not engine->is_maestro(this)) {
     XBT_DEBUG("Answer simcall %s issued by %s (%p)", SIMIX_simcall_name(simcall_), get_cname(), this);
     xbt_assert(simcall_.call_ != simix::Simcall::NONE);
     simcall_.call_ = simix::Simcall::NONE;
-    auto* engine              = EngineImpl::get_instance();
     const auto& actors_to_run = engine->get_actors_to_run();
     xbt_assert(not XBT_LOG_ISENABLED(simix_process, xbt_log_priority_debug) ||
                    std::find(begin(actors_to_run), end(actors_to_run), this) == end(actors_to_run),
@@ -474,7 +465,7 @@ ActorImpl* ActorImpl::start(const ActorCode& code)
 
   this->code_ = code;
   XBT_VERB("Create context %s", get_cname());
-  context_.reset(simix_global->get_context_factory()->create_context(ActorCode(code), this));
+  context_.reset(engine->get_context_factory()->create_context(ActorCode(code), this));
 
   XBT_DEBUG("Start context '%s'", get_cname());
 
@@ -509,60 +500,37 @@ ActorImplPtr ActorImpl::create(const std::string& name, const ActorCode& code, v
 
 void create_maestro(const std::function<void()>& code)
 {
+  auto* engine = EngineImpl::get_instance();
   /* Create maestro actor and initialize it */
   auto* maestro = new ActorImpl(xbt::string(""), /*host*/ nullptr);
 
   if (not code) {
-    maestro->context_.reset(simix_global->get_context_factory()->create_context(ActorCode(), maestro));
+    maestro->context_.reset(engine->get_context_factory()->create_context(ActorCode(), maestro));
   } else {
-    maestro->context_.reset(simix_global->get_context_factory()->create_maestro(ActorCode(code), maestro));
+    maestro->context_.reset(engine->get_context_factory()->create_maestro(ActorCode(code), maestro));
   }
 
-  maestro->simcall_.issuer_     = maestro;
-  simix_global->set_maestro(maestro);
+  maestro->simcall_.issuer_ = maestro;
+  engine->set_maestro(maestro);
 }
 
 } // namespace actor
 } // namespace kernel
 } // namespace simgrid
 
-int SIMIX_process_count() // XBT_ATTRIB_DEPRECATED_v329
+/* needs to be public and without simcall because it is called by exceptions and logging events */
+const char* SIMIX_process_self_get_name() // XBT_ATTRIB_DEPRECATED_v333
 {
-  return simgrid::kernel::EngineImpl::get_instance()->get_actor_list().size();
-}
-
-void* SIMIX_process_self_get_data() // XBT_ATTRIB_DEPRECATED_v329
-{
-  const simgrid::s4u::Actor* self = simgrid::s4u::Actor::self();
-  return self ? self->get_data() : nullptr;
-}
-
-void SIMIX_process_self_set_data(void* data) // XBT_ATTRIB_DEPRECATED_v329
-{
-  simgrid::s4u::Actor::self()->set_data(data);
-}
-
-/* needs to be public and without simcall because it is called
-   by exceptions and logging events */
-const char* SIMIX_process_self_get_name()
-{
-  return SIMIX_is_maestro() ? "maestro" : simgrid::kernel::actor::ActorImpl::self()->get_cname();
+  return simgrid::s4u::Actor::is_maestro() ? "maestro" : simgrid::kernel::actor::ActorImpl::self()->get_cname();
 }
 
 /** @brief Returns the process from PID. */
-smx_actor_t SIMIX_process_from_PID(aid_t pid) // XBT_ATTRIB_DEPRECATD_v331
+smx_actor_t SIMIX_process_from_PID(aid_t pid) // XBT_ATTRIB_DEPRECATED_v331
 {
   return simgrid::kernel::actor::ActorImpl::by_pid(pid);
 }
 
-void SIMIX_process_on_exit(smx_actor_t actor,
-                           const std::function<void(bool /*failed*/)>& fun) // XBT_ATTRIB_DEPRECATED_v329
+int SIMIX_is_maestro() // XBT_ATTRIB_DEPRECATED_v333
 {
-  xbt_assert(actor, "current process not found: are you in maestro context ?");
-  actor->on_exit->emplace_back(fun);
-}
-
-void simcall_process_set_data(smx_actor_t process, void* data) // XBT_ATTRIB_DEPRECATED_v329
-{
-  simgrid::kernel::actor::simcall([process, data] { process->get_ciface()->set_data(data); });
+  return simgrid::s4u::Actor::is_maestro();
 }
