@@ -3,11 +3,10 @@
 /* This program is free software; you can redistribute it and/or modify it
  * under the terms of the license (GNU LGPL) which comes with this package. */
 
-#include "simgrid/forward.h"
-#include "simgrid/mutex.h"
-#include "simgrid/s4u/Mutex.hpp"
-#include "src/kernel/activity/MutexImpl.hpp"
-#include "src/kernel/actor/SimcallObserver.hpp"
+#include <simgrid/mutex.h>
+#include <simgrid/s4u/Mutex.hpp>
+#include <src/kernel/activity/MutexImpl.hpp>
+#include <src/kernel/actor/SimcallObserver.hpp>
 
 namespace simgrid {
 namespace s4u {
